@@ -43,7 +43,8 @@ explore <- function(dataset,
   if (!is_empty(byvar)) tvars %<>% c(byvar) %>% unique
 
   dat <- getdata(dataset, tvars, filt = data_filter, na.rm = FALSE)
-  if (!is_string(dataset)) dataset <- "-----"
+  # if (!is_string(dataset)) dataset <- deparse(substitute(dataset))
+  if (!is_string(dataset)) dataset <- deparse(substitute(dataset)) %>% set_attr("df", TRUE)
 
   ## in case : was used
   vars <- colnames(head(dat) %>% select_(.dots = vars))
@@ -53,26 +54,29 @@ explore <- function(dataset,
   dc <- getclass(dat)
   isFctNum <- "factor" == dc & names(dc) %in% setdiff(vars,byvar)
   if (sum(isFctNum)) {
-    dat[,isFctNum] <- select(dat, which(isFctNum)) %>% mutate_each(funs(as.integer(. == levels(.)[1])))
+    dat[,isFctNum] <- select(dat, which(isFctNum)) %>% 
+      mutate_all(funs(as.integer(. == levels(.)[1])))
     dc[isFctNum] <- "integer"
   }
 
   isLogNum <- "logical" == dc & names(dc) %in% setdiff(vars,byvar)
   if (sum(isLogNum)) {
-    dat[,isLogNum] <- select(dat, which(isLogNum)) %>% mutate_each(funs(as.integer))
+    dat[,isLogNum] <- select(dat, which(isLogNum)) %>% 
+      mutate_all(funs(as.integer))
     dc[isLogNum] <- "integer"
   }
 
   ## summaries only for numeric variables
-  isNum <- dc %>% {which("numeric" == . | "integer" == .)}
+  # isNum <- dc %>% {which("numeric" == . | "integer" == .)}
 
   ## avoid using .._rm as function name
   pfun <- make_funs(fun)
 
   if (is_empty(byvar)) {
-    tab <- dat %>% select(isNum) %>%
+    isNum <- dc %>% {which("numeric" == . | "integer" == .)}
+    tab <- dat %>% select_(.dots = names(isNum)) %>%
       gather("variable", "value", factor_key = TRUE) %>%
-      group_by_("variable")  %>% summarise_each(pfun)
+      group_by_("variable")  %>% summarise_all(pfun)
 
     ## order by the variable names selected
     tab <- tab[match(vars, tab[[1]]),]
@@ -82,7 +86,8 @@ explore <- function(dataset,
 
     ## convert categorical variables to factors if needed
     ## needed to deal with empty/missing values
-    dat[,byvar] <- select_(dat, .dots = byvar) %>% mutate_each(funs(empty_level(.)))
+    dat[,byvar] <- select_(dat, .dots = byvar) %>% 
+      mutate_all(funs(empty_level(.)))
 
     ## avoiding issues with n_missing and n_distinct in dplyr
     ## have to reverse this later
@@ -97,7 +102,7 @@ explore <- function(dataset,
     names(pfun) %<>% fix_uscore
 
     tab <- dat %>% group_by_(.dots = byvar) %>%
-      summarise_each(pfun)
+      summarise_all(pfun)
 
     ## avoiding issues with n_missing and n_distinct
     names(pfun) %<>% sub("n.","n_",.)
@@ -131,7 +136,8 @@ explore <- function(dataset,
   ## sorting the table if desired from R > Report
   if (!identical(tabsort, "")) {
     if (grepl(",", tabsort))
-      tabsort <- strsplit(tabsort,",")[[1]] %>% gsub(" ", "", .)
+      tabsort <- strsplit(tabsort,",")[[1]] %>% gsub("^\\s+|\\s+$", "", .)
+
     tab %<>% arrange_(.dots = tabsort)
   }
 
@@ -141,14 +147,15 @@ explore <- function(dataset,
 
   ## frequencies turned into doubles earlier ...
   check_int <- function(x) {
-    if (is.numeric(x)) {
+    if (is.double(x) && length(na.omit(x)) > 0) {
       x_int <- as.integer(round(x,.Machine$double.rounding))
-      if (all(x == x_int)) x <- x_int
+      if (all(x == x_int)) x_int else x
+    } else {
+      x
     }
-    x
   }
 
-  tab <- mutate_each(tab, funs(check_int))
+  tab <- ungroup(tab) %>% mutate_all(funs(check_int))
 
   ## convert to data.frame to maintain attributes
   tab <- as.data.frame(tab, as.is = TRUE)
@@ -220,6 +227,9 @@ summary.explore <- function(object, dec = 3, ...) {
 store.explore <- function(object, name, ...) {
   tab <- object$tab
 
+  ## fix colnames as needed
+  colnames(tab) <- sub("^\\s+","", colnames(tab)) %>% sub("\\s+$","", .) %>% gsub("\\s+", "_", .)
+
   if (exists("r_environment")) {
     env <- r_environment
   } else if (exists("r_data")) {
@@ -257,7 +267,9 @@ flip <- function(expl, top = "fun") {
   } else if (top[1] == "byvar" && length(cvars) > 0) {
     expl$tab %<>% gather(".function", "value", -(1:(length(cvars)+1))) %>% spread_(cvars[1], "value")
     expl$tab[[".function"]] %<>% factor(., levels = names(expl$pfun))
-    colnames(expl$tab) <- gsub(" ", ".", colnames(expl$tab))
+
+    ## ensure we don't have invalid column names
+    colnames(expl$tab) <- make.names(colnames(expl$tab))
   }
 
   expl$tab
@@ -512,6 +524,66 @@ se <- function(x, na.rm = TRUE) {
   sd(x) / sqrt(length(x))
 }
 
+#' Calculate proportion
+#' @param x Input variable
+#' @param na.rm If TRUE missing values are removed before calculation
+#' @return Proportion of first level for a factor and of the maximum value for numeric
+#' @examples
+#' prop(c(rep(1L, 10), rep(0L, 10)))
+#' prop(c(rep(4, 10), rep(2, 10)))
+#' prop(rep(0, 10))
+#' prop(factor(c(rep("a", 20), rep("b", 10))))
+#'
+#' @export
+prop <- function(x, na.rm = TRUE) {
+  if (na.rm) x <- na.omit(x)
+  if (is.numeric(x)) {
+    mean(x == max(x, 1))     ## gives proportion of max value in x
+  } else if (is.factor(x)) {
+    mean(x == levels(x)[1])  ## gives proportion of first level in x
+  } else if (is.logical(x)) {
+    mean(x)
+  } else {
+    NA
+  }
+}
+
+#' Variance for proportion
+#' @param x Input variable
+#' @param na.rm If TRUE missing values are removed before calculation
+#' @return Variance for proportion
+#' @examples
+#' varprop(c(rep(1L, 10), rep(0L, 10)))
+#'
+#' @export
+varprop <- function(x, na.rm = TRUE) {
+  p <- prop(x, na.rm = na.rm)
+  p*(1-p)
+}
+
+#' Standard deviation for proportion
+#' @param x Input variable
+#' @param na.rm If TRUE missing values are removed before calculation
+#' @return Standard deviation for proportion
+#' @examples
+#' sdprop(c(rep(1L, 10), rep(0L, 10)))
+#'
+#' @export
+sdprop <- function(x, na.rm = TRUE) sqrt(varprop(x, na.rm = na.rm))
+
+#' Standard error for proportion
+#' @param x Input variable
+#' @param na.rm If TRUE missing values are removed before calculation
+#' @return Standard error for proportion
+#' @examples
+#' seprop(c(rep(1L, 10), rep(0L, 10)))
+#'
+#' @export
+seprop <- function(x, na.rm = TRUE) {
+  if (na.rm) x <- na.omit(x)
+  sqrt(varprop(x, na.rm = FALSE)/length(x))
+}
+
 #' Variance with na.rm = TRUE
 #' @param x Input variable
 #' @param na.rm If TRUE missing values are removed before calculation
@@ -522,29 +594,29 @@ se <- function(x, na.rm = TRUE) {
 #' @export
 var_rm <- function(x, na.rm = TRUE) var(x, na.rm = na.rm)
 
-#' Variance for the population na.rm = TRUE
+#' Variance for the population
 #' @param x Input variable
 #' @param na.rm If TRUE missing values are removed before calculation
 #' @return Variance for the population
 #' @examples
-#' varp_rm(rnorm(100))
+#' varpop(rnorm(100))
 #'
 #' @export
-varp_rm <- function(x, na.rm = TRUE) {
+varpop <- function(x, na.rm = TRUE) {
   if (na.rm) x <- na.omit(x)
   n <- length(x)
   var(x) * ((n-1)/n)
 }
 
-#' Standard deviation for the population na.rm = TRUE
+#' Standard deviation for the population
 #' @param x Input variable
 #' @param na.rm If TRUE missing values are removed before calculation
 #' @return Standard deviation for the population
 #' @examples
-#' sdp_rm(rnorm(100))
+#' sdpop(rnorm(100))
 #'
 #' @export
-sdp_rm <- function(x, na.rm = TRUE) sqrt(varp_rm(x, na.rm = na.rm))
+sdpop <- function(x, na.rm = TRUE) sqrt(varpop(x, na.rm = na.rm))
 
 #' Sum with na.rm = TRUE
 #' @param x Input variable
@@ -571,7 +643,7 @@ ln <- function(x, na.rm = TRUE) if (na.rm) log(na.omit(x)) else log(x)
 #' @param na.rm If TRUE missing values are removed before calculation
 #' @return Logical. TRUE is there is variability
 #' @examples
-#' summarise_each(diamonds, funs(does_vary)) %>% as.logical
+#' summarise_all(diamonds, funs(does_vary)) %>% as.logical
 #'
 #' @export
 does_vary <- function(x, na.rm = TRUE) {
@@ -580,7 +652,7 @@ does_vary <- function(x, na.rm = TRUE) {
     FALSE
   } else {
     if (is.factor(x) || is.character(x)) {
-      n_distinct(x, na.rm = na.rm) > 1
+      length(unique(x)) > 1
     } else {
       abs(max_rm(x, na.rm = na.rm) - min_rm(x, na.rm = na.rm)) > .Machine$double.eps^0.5
     }
