@@ -302,7 +302,7 @@ loadcsv <- function(fn, .csv = FALSE, header = TRUE, sep = ",", dec = ".", n_max
 
   if (is(dat, 'try-error')) return("### There was an error loading the data. Please make sure the data are in csv format.")
   if (saf) dat <- factorizer(dat, safx)
-  as.data.frame(dat) %>% set_attr("description", rprob)
+  dat %>% {set_colnames(., make.names(colnames(.)))} %>% set_attr("description", rprob)
 }
 
 #' Load a csv file with from a url
@@ -339,7 +339,7 @@ loadcsv_url <- function(csv_url, header = TRUE, sep = ",", dec = ".", n_max = In
 
     if (saf) dat <- factorizer(dat, safx)
 
-    dat
+    dat %>% {set_colnames(., make.names(colnames(.)))}
   }
 }
 
